package edu.travel.filter;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.nimbusds.jose.JWSObject;
import edu.travel.EncryptUtil;
import edu.travel.FinalParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.cloud.gateway.filter.GatewayFilterChain;
import org.springframework.cloud.gateway.filter.GlobalFilter;
import org.springframework.core.Ordered;
import org.springframework.http.server.reactive.ServerHttpRequest;
import org.springframework.stereotype.Component;
import org.springframework.web.server.ServerWebExchange;
import reactor.core.publisher.Mono;

import java.text.ParseException;
import java.util.*;

@Component
public class GateWayFilter implements GlobalFilter, Ordered {
    @Override
    public Mono<Void> filter(ServerWebExchange exchange, GatewayFilterChain chain) {
        //获取到token
        String token = exchange.getRequest().getHeaders().getFirst("Authorization");
        if (StringUtils.isBlank(token) || token.equals("null")) {
            return chain.filter(exchange);
        }
        //替换token
        String realToken = token.replace("Bearer ", "");
        try {
            JWSObject jwsObject = JWSObject.parse(realToken);
            String userStr = jwsObject.getPayload().toString();
            JSONObject jsonObject = JSON.parseObject(userStr);
//            Object object = jsonObject.get(FinalParam.AUTHORITY_CLAIM_NAME);
//            List<String> authorities = new ArrayList<String>();
//            if (object != null){
//                String all = jsonObject.get(FinalParam.AUTHORITY_CLAIM_NAME).toString().replaceAll("\"", "");
//                String[] split = all.substring(all.indexOf("[") + 1, all.length() - 1).split(",");
//                authorities = new ArrayList<String>(Arrays.asList(split));
//            }
            Object object = jsonObject.get(FinalParam.AUTHORITY_CLAIM_NAME);
            List<String> authorities = new ArrayList<>();

            if (object != null) {
                // 如果权限字段是 JSONArray 类型
                if (object instanceof JSONArray) {
                    authorities = ((JSONArray) object).toJavaList(String.class);
                } else {
                    // 如果权限字段是字符串类型
                    String authoritiesStr = object.toString();
                    JSONArray authoritiesArray = JSON.parseArray(authoritiesStr);
                    authorities = authoritiesArray.toJavaList(String.class);
                }
            }
            String principal = jsonObject.getObject("user_name", String.class);
            String client_id = jsonObject.getObject("client_id", String.class);
            Map<String, Object> map = new HashMap<>();
            //获取权限
            System.out.println("Authorities: " + authorities);
            map.put("authorities", authorities);
            //获取客户端
            map.put("client_id", client_id);
            //获取用户
            map.put("principal", principal);
            String tokens = EncryptUtil.encodeUTF8StringBase64(JSON.toJSONString(map));
            ServerHttpRequest request = exchange.getRequest().mutate().header("token", tokens).build();
            exchange = exchange.mutate().request(request).build();
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return chain.filter(exchange);
    }

    @Override
    public int getOrder() {
        return 0;
    }
}
