package edu.travel.tenant.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;

import java.io.Serializable;
import java.util.Date;
import java.util.Map;

import edu.travel.annotation.LinkConst;
import edu.travel.entity.BaseEntity;
import edu.travel.tenant.entity.dict.EnableDict;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * 菜单表
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@TableName(value = "sys_menu")
public class SysMenu extends BaseEntity implements Serializable {
    /**
     * 主键id
     */
    @TableId(value = "id", type = IdType.ASSIGN_ID)
    private Long id;

    /**
     * 父菜单id，目录菜单的父菜单为null
     */
    @TableField(value = "parent_id")
    private Long parentId;

    /**
     * 前端表单路由名称，仅用于menu_type为1的菜单类型
     */
    @TableField(value = "title")
    private String title;

    /**
     * (0: 目录 1: 菜单 2: 按钮 )
     */
    @TableField(value = "`type`")
    private Integer type;

    /**
     * 组件路径
     */
    @TableField(value = "component")
    private String component;

    /**
     * 页面路由
     */
    @TableField(value = "`path`")
    private String path;

    /**
     * 组件名称
     */
    @TableField(value = "`name`")
    private String name;

    /**
     * 菜单状态 0禁用1启用
     */
    @TableField(value = "`status`")
    private Byte status;

    /**
     * 菜单是否启用
     */
    @TableField(exist = false)
    @LinkConst(fieldName = "status",clazz = EnableDict.class)
    private Map codeEnableDict;

    /**
     * 是否缓存字典
     */
    @TableField(exist = false)
    @LinkConst(fieldName = "type",clazz = EnableDict.class)
    private Map codeMenuTypeDict;

}